@@ -16,6 +16,7 @@ import shlex
 import re
 from collections import deque
 from surftrace import CexecCmd
+from datetime import datetime
 
 HIST2_MAX = 65
 HIST10_MAX = 20
@@ -142,12 +143,14 @@ def _splitArgs(line, sym):
             argd[k] = v
     return argd
 
+
 def _transSysExit(line, res):
     # 447379.740962: sys_futex -> 0x0
     name, val = line.split("->")
     res["name"] = name.strip()
     res["return"] = int(val, 16)
 
+
 def _transSysEntry(line, res):
     # futex(uaddr: 7f1a90bc9910, op: 0, val: 19989, utime: 0, uaddr2: 0, val3: 7f1a903c8640)
     name, rest = line.split('(', 1)
@@ -159,10 +162,11 @@ def _transSysEntry(line, res):
         argd[k] = v.strip()
     res['argd'] = argd
 
+
 def _transEvents(line, res):
-    name, rest = line.split(':', 1)
+    name, rest = line.split(':', 1)  # do not parse events format.
     res['name'] = name
-    res['args'] = _splitArgs(rest, '=')
+    res['args'] = rest.strip()
 
 
 def _transProbe(line, res):
@@ -184,6 +188,7 @@ def transProbeLine(line):
     '''kworker/u4:0-103806  [000] d... 445702.516774: sched_stat_wait: comm=bash pid=103869 delay=1843 [ns]'''
     '''sem-104831  [001] .... 448036.804764: sys_futex(uaddr: 7f1a90bc9910, op: 0, val: 19989, utime: 0, uaddr2: 0, val3: 7f1a903c8640)'''
     '''sem-104831  [001] .... 448036.804808: sys_futex -> 0x0'''
+    '''kworker/1:1H-115     [001] .... 651700.858481: block_rq_issue: 253,0 FF 0 () 0 + 0 [kworker/1:1H]'''
     tasks, rest = line.split(" [", 1)
     task, pid = tasks.strip().rsplit('-', 1)
     res = {"task": task, "pid": int(pid)}
@@ -200,7 +205,7 @@ def transProbeLine(line):
         _transSysEntry(rest, res)
     elif re.match(r"\w+ -> \w+", rest): #syscall exit
         _transSysExit(rest, res)
-    elif re.match(r"\w+:", rest):    # events
+    elif re.match(r"\w+: ", rest):    # events
         _transEvents(rest, res)
     elif re.match(r"\w{%d}" % len(rest), rest):
         res['name'] = rest
@@ -209,14 +214,14 @@ def transProbeLine(line):
     return res
 
 if __name__ == "__main__":
-    print(transProbeLine(
-        'jbd2/vda1-8-313   [000] .... 234372.103866: f0: (blk_account_io_start+0x0/0x180) request=18446617219543870720 disk="vda" comm="jbd2/vda1-8"'))
-    print(transProbeLine(
-        'kworker/u4:0-103806  [000] d... 445702.516774: sched_stat_wait: comm=bash pid=103869 delay=1843 [ns]'))
-    print(transProbeLine(
-        'kworker/u4:0-103806  [000] d... 445702.516774: sched_stat_wait'))
-    print(transProbeLine(
-        'sem-104831  [001] .... 448036.804764: sys_futex(uaddr: 7f1a90bc9910, op: 0, val: 19989, utime: 0, uaddr2: 0, val3: 7f1a903c8640)'))
-    print(transProbeLine('sem-104831  [001] .... 448036.804808: sys_futex -> 0x0'))
-    print(transProbeLine(
-        'kworker/u4:0-103806  [000] d... 445702.516774: sched_stat_wait'))
\ No newline at end of file
+    # print(transProbeLine(
+    #     'jbd2/vda1-8-313   [000] .... 234372.103866: f0: (blk_account_io_start+0x0/0x180) request=18446617219543870720 disk="vda" comm="jbd2/vda1-8"'))
+    # print(transProbeLine(
+    #     'kworker/u4:0-103806  [000] d... 445702.516774: sched_stat_wait: comm=bash pid=103869 delay=1843 [ns]'))
+    # print(transProbeLine(
+    #     'kworker/u4:0-103806  [000] d... 445702.516774: sched_stat_wait'))
+    # print(transProbeLine(
+    #     'sem-104831  [001] .... 448036.804764: sys_futex(uaddr: 7f1a90bc9910, op: 0, val: 19989, utime: 0, uaddr2: 0, val3: 7f1a903c8640)'))
+    # print(transProbeLine('sem-104831  [001] .... 448036.804808: sys_futex -> 0x0'))
+    # print(transProbeLine('kworker/u4:0-103806  [000] d... 445702.516774: sched_stat_wait'))
+    print(transProbeLine('kworker/1:1H-115     [001] .... 651700.858481: block_rq_issue: 253,0 FF 0 () 0 + 0 [kworker/1:1H]'))
\ No newline at end of file
